@@ -66,6 +66,7 @@ tar_files_input_raw <- function(
   files,
   batches = length(files),
   format = c("file", "url", "aws_file"),
+  repository = targets::tar_option_get("repository"),
   iteration = targets::tar_option_get("iteration"),
   error = targets::tar_option_get("error"),
   memory = targets::tar_option_get("memory"),
@@ -89,6 +90,7 @@ tar_files_input_raw <- function(
     pattern = NULL,
     packages = character(0),
     format = "rds",
+    repository = repository,
     iteration = "list",
     error = error,
     memory = memory,
@@ -107,6 +109,7 @@ tar_files_input_raw <- function(
     pattern = as.expression(call_function("map", list(name_files_sym))),
     packages = character(0),
     format = format,
+    repository = repository,
     iteration = iteration,
     error = error,
     memory = memory,
