@@ -49,6 +49,7 @@ tar_force <- function(
   packages = targets::tar_option_get("packages"),
   library = targets::tar_option_get("library"),
   format = targets::tar_option_get("format"),
+  repository = targets::tar_option_get("repository"),
   iteration = targets::tar_option_get("iteration"),
   error = targets::tar_option_get("error"),
   memory = targets::tar_option_get("memory"),
@@ -74,6 +75,7 @@ tar_force <- function(
     packages = packages,
     library = library,
     format = format,
+    repository = repository,
     iteration = iteration,
     error = error,
     memory = memory,
