@@ -46,6 +46,7 @@ tar_format <- function(format) {
       packages = packages,
       library = library,
       format = format,
+      repository = repository,
       iteration = iteration,
       error = error,
       memory = memory,
@@ -68,6 +69,7 @@ tar_format_api <- function(
   tidy_eval = targets::tar_option_get("tidy_eval"),
   packages = targets::tar_option_get("packages"),
   library = targets::tar_option_get("library"),
+  repository = targets::tar_option_get("repository"),
   iteration = targets::tar_option_get("iteration"),
   error = targets::tar_option_get("error"),
   memory = targets::tar_option_get("memory"),
