@@ -50,6 +50,7 @@ tar_map2 <- function(
   packages = targets::tar_option_get("packages"),
   library = targets::tar_option_get("library"),
   format = targets::tar_option_get("format"),
+  repository = targets::tar_option_get("repository"),
   error = targets::tar_option_get("error"),
   memory = targets::tar_option_get("memory"),
   deployment = targets::tar_option_get("deployment"),
@@ -75,6 +76,7 @@ tar_map2 <- function(
     packages = packages,
     library = library,
     format = format,
+    repository = repository,
     error = error,
     memory = memory,
     deployment = deployment,
