@@ -50,6 +50,7 @@ tar_map2_raw <- function(
   packages = targets::tar_option_get("packages"),
   library = targets::tar_option_get("library"),
   format = targets::tar_option_get("format"),
+  repository = targets::tar_option_get("repository"),
   error = targets::tar_option_get("error"),
   memory = targets::tar_option_get("memory"),
   deployment = targets::tar_option_get("deployment"),
@@ -104,6 +105,7 @@ tar_map2_raw <- function(
     packages = packages,
     library = library,
     format = format,
+    repository = repository,
     iteration = "group",
     error = error,
     memory = memory,
@@ -121,6 +123,7 @@ tar_map2_raw <- function(
     packages = packages,
     library = library,
     format = format,
+    repository = repository,
     iteration = "vector",
     error = error,
     memory = memory,
@@ -155,6 +158,7 @@ tar_map2_raw <- function(
       use_names = TRUE,
       packages = character(0),
       format = format,
+      repository = repository,
       iteration = "group",
       error = error,
       memory = memory,
