@@ -1,6 +1,6 @@
 targets::tar_test("knitr_deps() on a bad report", {
   writeLines(c("```{r}", "1 <-", "```"), "report.Rmd")
-  expect_error(knitr_deps("report.Rmd"), class = "condition_validate")
+  expect_error(knitr_deps("report.Rmd"), class = "tar_condition_validate")
 })
 
 targets::tar_test("knitr_deps()", {
@@ -20,7 +20,7 @@ targets::tar_test("walk_call_knitr() warns on empty tar_load()", {
   expr <- quote(tar_load())
   expect_warning(
     out <- walk_ast(expr, walk_call_knitr),
-    class = "condition_validate"
+    class = "tar_condition_validate"
   )
   expect_equal(out, character(0))
 })
@@ -29,7 +29,7 @@ targets::tar_test("walk_call_knitr() warns on empty tar_read()", {
   expr <- quote(tar_read())
   expect_warning(
     out <- walk_ast(expr, walk_call_knitr),
-    class = "condition_validate"
+    class = "tar_condition_validate"
   )
   expect_equal(out, character(0))
 })
@@ -38,7 +38,7 @@ targets::tar_test("walk_call_knitr() warns on tidyselect", {
   expr <- quote(tar_load(starts_with("xyz")))
   expect_warning(
     out <- walk_ast(expr, walk_call_knitr),
-    class = "condition_validate"
+    class = "tar_condition_validate"
   )
   expect_equal(out, character(0))
 })
